# THL

this is a readme for Turtle Helper Libary.
T.H.L. is a py lib that makes coding with turtle even easer. the turtle it creates is named tur. the function list can be found at tinyurl.com/turtlehldoc